==> docs_sdk_archive_luna-sdk_droid_complete_rel_v.4.9.0.zip: docs_sdk_archive_luna-sdk_droid_complete_rel_v.4.9.0/doc/fsdk/html/structfsdk_1_1_format.js <==
var structfsdk_1_1_format =
[
    [ "Type", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1", [
      [ "Unknown", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a28e996e86d8357a023f9b14fa4da9f1f", null ],
      [ "B8G8R8X8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a2c186c232b67f3d47add72abea686242", null ],
      [ "R8G8B8X8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a1531807037bb455d89b70ff0d6ff05fe", null ],
      [ "B8G8R8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a9bda0cc528d54cecc7f8ec2a3b3ad5c8", null ],
      [ "R8G8B8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a64d817782ee8b40de7073acc65267e76", null ],
      [ "R8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1afd28eabff68ce04d89a4a445c8774f11", null ],
      [ "R16", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1ae6596410cdfb3e164d3114d7275c01a4", null ],
      [ "IR_X8X8X8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1af4ca5a5a1ea5b7005c89a9cd0911d0b4", null ],
      [ "YUV_NV21", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a86ae1133449f6210391a331405d7ea4e", null ]
    ] ],
    [ "Format", "structfsdk_1_1_format.html#aa45f2da762d2fce103d97aa803078d84", null ],
    [ "Format", "structfsdk_1_1_format.html#a9fae615ad7c67630f9546abd6d568175", null ],
    [ "computePitch", "structfsdk_1_1_format.html#aea650b3b3a3256b34cf1284c53262899", null ],
    [ "getBitDepth", "structfsdk_1_1_format.html#ae3136cd08cf4395b3250950eb820bc74", null ],
    [ "getByteDepth", "structfsdk_1_1_format.html#afd04839a40f2a3b875038ec233b4a8eb", null ],
    [ "getChannelCount", "structfsdk_1_1_format.html#a5654c8e7485f5821a0b77c40150144ea", null ],
    [ "getChannelSize", "structfsdk_1_1_format.html#a1ed1e226b132c165793edfe88c21a4ee", null ],
    [ "getChannelStep", "structfsdk_1_1_format.html#ad18bb21ae3c7577a0ebd3eca67fc26a9", null ],
    [ "isBGR", "structfsdk_1_1_format.html#a4f1a89d82820cc5461d983700d2191d1", null ],
    [ "isBlock", "structfsdk_1_1_format.html#a46d028b666e796b8021e8cce7bc90c9e", null ],
    [ "isPadded", "structfsdk_1_1_format.html#a43ca12b83363226c0459e6a1b5073550", null ],
    [ "isValid", "structfsdk_1_1_format.html#a0cebf5379f7e7f173ae64d35f0ab9670", null ],
    [ "isYUV", "structfsdk_1_1_format.html#a9774699a7b4642bf36ce9f42032a5cb9", null ],
    [ "operator Type", "structfsdk_1_1_format.html#ad603c8ad2250b23f3cbaa04fa69e9d29", null ],
    [ "m_type", "structfsdk_1_1_format.html#a708cc1ef87c456417c678e7720a52159", null ]
];

==> docs_sdk_archive_luna-sdk_droid_complete_rel_v.5.2.0.zip: docs_sdk_archive_luna-sdk_droid_complete_rel_v.5.2.0/doc/fsdk/html/structfsdk_1_1_format.js <==
var structfsdk_1_1_format =
[
    [ "Type", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1", [
      [ "Unknown", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a28e996e86d8357a023f9b14fa4da9f1f", null ],
      [ "B8G8R8X8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a2c186c232b67f3d47add72abea686242", null ],
      [ "R8G8B8X8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a1531807037bb455d89b70ff0d6ff05fe", null ],
      [ "B8G8R8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a9bda0cc528d54cecc7f8ec2a3b3ad5c8", null ],
      [ "R8G8B8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a64d817782ee8b40de7073acc65267e76", null ],
      [ "R8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1afd28eabff68ce04d89a4a445c8774f11", null ],
      [ "R16", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1ae6596410cdfb3e164d3114d7275c01a4", null ],
      [ "IR_X8X8X8", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1af4ca5a5a1ea5b7005c89a9cd0911d0b4", null ],
      [ "YUV_NV21", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a86ae1133449f6210391a331405d7ea4e", null ],
      [ "YUV_NV12", "structfsdk_1_1_format.html#a9074e215a3c98d8e5b125bbec8d19af1a7acff06144acdfb863cfe120628e9d56", null ]
    ] ],
    [ "Format", "structfsdk_1_1_format.html#aa45f2da762d2fce103d97aa803078d84", null ],
    [ "Format", "structfsdk_1_1_format.html#a9fae615ad7c67630f9546abd6d568175", null ],
    [ "computePitch", "structfsdk_1_1_format.html#aea650b3b3a3256b34cf1284c53262899", null ],
    [ "getBitDepth", "structfsdk_1_1_format.html#ae3136cd08cf4395b3250950eb820bc74", null ],
    [ "getByteDepth", "structfsdk_1_1_format.html#afd04839a40f2a3b875038ec233b4a8eb", null ],
    [ "getChannelCount", "structfsdk_1_1_format.html#a5654c8e7485f5821a0b77c40150144ea", null ],
    [ "getChannelSize", "structfsdk_1_1_format.html#a1ed1e226b132c165793edfe88c21a4ee", null ],
    [ "getChannelStep", "structfsdk_1_1_format.html#ad18bb21ae3c7577a0ebd3eca67fc26a9", null ],
    [ "isBGR", "structfsdk_1_1_format.html#a4f1a89d82820cc5461d983700d2191d1", null ],
    [ "isBlock", "structfsdk_1_1_format.html#a46d028b666e796b8021e8cce7bc90c9e", null ],
    [ "isPadded", "structfsdk_1_1_format.html#a43ca12b83363226c0459e6a1b5073550", null ],
    [ "isValid", "structfsdk_1_1_format.html#a0cebf5379f7e7f173ae64d35f0ab9670", null ],
    [ "isYUV", "structfsdk_1_1_format.html#a9774699a7b4642bf36ce9f42032a5cb9", null ],
    [ "operator Type", "structfsdk_1_1_format.html#ad603c8ad2250b23f3cbaa04fa69e9d29", null ],
    [ "m_type", "structfsdk_1_1_format.html#a708cc1ef87c456417c678e7720a52159", null ]
];
